@@ -5,63 +5,7 @@ use warnings;
 use HTTP::Tiny;
 use JSON;
 
-$Yandex::Translate::VERSION = '0.01';
-
-=head1 NAME
-
-Yandex::Translate - Perl extension for using Yandex API
-
-=head1 SYNOPSIS
-  #Calling the module
-  use Yandex::Translate; #Calling the module
-  
-  #Create an instance
-  my $tr = Yandex::Translate->new;
-
-  #Set API key, you can get from https://translate.yandex.com/developers/keys
-  $tr->set_key('your_api_key');
-  
-  #Select the lang that you want to translate from
-  $tr->set_from_lang("en");
-  
-  #Select the lang that you want  to translate to
-  $tr->set_to_lang("ru");
-   
-  #Set the text that you want to translate
-  $tr->set_to_lang("Hello Perl");
-  
-  #Get the result
-  print $tr->translate();
-
-=head1 DESCRIPTION
-
-Yandex.Translate (previously Yandex.Translation) is a web service 
-provided by Yandex intended for the translation of text or web pages 
-into another language.
-
-The service uses a self-learning statistical machine translation,
-developed by Yandex.
-The system constructs the dictionary of correspondences based 
-on the analysis of millions of translated texts.
-
-=head1 SEE ALSO
-For more info please visit Yandex https://translate.yandex.com/developers
-
-
-=head1 AUTHOR
-
-James Axl, E<lt>axlrose112@gmail.comE<gt>
-
-=head1 COPYRIGHT AND LICENSE
-
-Copyright (C) 2017 by James Axl
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.24.1 or,
-at your option, any later version of Perl 5 you may have available.
-
-
-=cut
+$Yandex::Translate::VERSION = '0.02';
 
 sub new
 {
